@@ -295,16 +295,16 @@ public:
         quality with respect to possible tearing and timings.
       
   */
-struct presentation_feedback_kind : public detail::bitfield<4, 1>
+struct presentation_feedback_kind : public wayland::detail::bitfield<4, 1>
 {
-  presentation_feedback_kind(const detail::bitfield<4, 1> &b)
-    : detail::bitfield<4, 1>(b) {}
+  presentation_feedback_kind(const wayland::detail::bitfield<4, 1> &b)
+    : wayland::detail::bitfield<4, 1>(b) {}
   presentation_feedback_kind(const uint32_t value)
-    : detail::bitfield<4, 1>(value) {}
-  static const detail::bitfield<4, 1> vsync;
-  static const detail::bitfield<4, 1> hw_clock;
-  static const detail::bitfield<4, 1> hw_completion;
-  static const detail::bitfield<4, 1> zero_copy;
+    : wayland::detail::bitfield<4, 1>(value) {}
+  static const wayland::detail::bitfield<4, 1> vsync;
+  static const wayland::detail::bitfield<4, 1> hw_clock;
+  static const wayland::detail::bitfield<4, 1> hw_completion;
+  static const wayland::detail::bitfield<4, 1> zero_copy;
 };
 
 
@@ -933,19 +933,19 @@ enum class xdg_positioner_gravity : uint32_t
 	Flip, 2) Slide, 3) Resize.
       
   */
-struct xdg_positioner_constraint_adjustment : public detail::bitfield<6, 8>
+struct xdg_positioner_constraint_adjustment : public wayland::detail::bitfield<6, 8>
 {
-  xdg_positioner_constraint_adjustment(const detail::bitfield<6, 8> &b)
-    : detail::bitfield<6, 8>(b) {}
+  xdg_positioner_constraint_adjustment(const wayland::detail::bitfield<6, 8> &b)
+    : wayland::detail::bitfield<6, 8>(b) {}
   xdg_positioner_constraint_adjustment(const uint32_t value)
-    : detail::bitfield<6, 8>(value) {}
-  static const detail::bitfield<6, 8> none;
-  static const detail::bitfield<6, 8> slide_x;
-  static const detail::bitfield<6, 8> slide_y;
-  static const detail::bitfield<6, 8> flip_x;
-  static const detail::bitfield<6, 8> flip_y;
-  static const detail::bitfield<6, 8> resize_x;
-  static const detail::bitfield<6, 8> resize_y;
+    : wayland::detail::bitfield<6, 8>(value) {}
+  static const wayland::detail::bitfield<6, 8> none;
+  static const wayland::detail::bitfield<6, 8> slide_x;
+  static const wayland::detail::bitfield<6, 8> slide_y;
+  static const wayland::detail::bitfield<6, 8> flip_x;
+  static const wayland::detail::bitfield<6, 8> flip_y;
+  static const wayland::detail::bitfield<6, 8> resize_x;
+  static const wayland::detail::bitfield<6, 8> resize_y;
 };
 
 
@@ -1700,21 +1700,21 @@ enum class xdg_toplevel_error : uint32_t
 	is being dragged in a resize operation.
       
   */
-struct xdg_toplevel_resize_edge : public detail::bitfield<4, 11>
+struct xdg_toplevel_resize_edge : public wayland::detail::bitfield<4, 11>
 {
-  xdg_toplevel_resize_edge(const detail::bitfield<4, 11> &b)
-    : detail::bitfield<4, 11>(b) {}
+  xdg_toplevel_resize_edge(const wayland::detail::bitfield<4, 11> &b)
+    : wayland::detail::bitfield<4, 11>(b) {}
   xdg_toplevel_resize_edge(const uint32_t value)
-    : detail::bitfield<4, 11>(value) {}
-  static const detail::bitfield<4, 11> none;
-  static const detail::bitfield<4, 11> top;
-  static const detail::bitfield<4, 11> bottom;
-  static const detail::bitfield<4, 11> left;
-  static const detail::bitfield<4, 11> top_left;
-  static const detail::bitfield<4, 11> bottom_left;
-  static const detail::bitfield<4, 11> right;
-  static const detail::bitfield<4, 11> top_right;
-  static const detail::bitfield<4, 11> bottom_right;
+    : wayland::detail::bitfield<4, 11>(value) {}
+  static const wayland::detail::bitfield<4, 11> none;
+  static const wayland::detail::bitfield<4, 11> top;
+  static const wayland::detail::bitfield<4, 11> bottom;
+  static const wayland::detail::bitfield<4, 11> left;
+  static const wayland::detail::bitfield<4, 11> top_left;
+  static const wayland::detail::bitfield<4, 11> bottom_left;
+  static const wayland::detail::bitfield<4, 11> right;
+  static const wayland::detail::bitfield<4, 11> top_right;
+  static const wayland::detail::bitfield<4, 11> bottom_right;
 };
 
 /** \brief types of state on the surface
